<?php

namespace Project\Project\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Project\Project\Http\Requests\BrmagazinRequest;
use Project\Project\Interfaces\BrmagazinRepositoryInterface;
use Project\Project\Models\Brmagazin;
use Project\Project\Forms\Brmagazin as Form;

/**
 * APIController  class for brmagazin.
 */
class BrmagazinAPIController extends BaseController
{

    /**
     * Initialize brmagazin resource controller.
     *
     * @param type BrmagazinRepositoryInterface $brmagazin
     *
     * @return null
     */
    public function __construct(BrmagazinRepositoryInterface $brmagazin)
    {
        parent::__construct();
        $this->repository = $brmagazin;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Project\Project\Repositories\Criteria\BrmagazinResourceCriteria::class);
    }

    /**
     * Display a list of brmagazin.
     *
     * @return Response
     */
    public function index(BrmagazinRequest $request)
    {
        return $this->repository
            ->setPresenter(\Project\Project\Repositories\Presenter\BrmagazinPresenter::class)
            ->paginate();
    }

    /**
     * Display brmagazin.
     *
     * @param Request $request
     * @param Model   $brmagazin
     *
     * @return Response
     */
    public function show(BrmagazinRequest $request, Brmagazin $brmagazin)
    {
        return $brmagazin->setPresenter(\Project\Project\Repositories\Presenter\BrmagazinListPresenter::class);
        ;
    }

    /**
     * Create new brmagazin.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BrmagazinRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('project::brmagazin.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('project/brmagazin/' . $brmagazin->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('project/brmagazin');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the brmagazin.
     *
     * @param Request $request
     * @param Model   $brmagazin
     *
     * @return Response
     */
    public function update(BrmagazinRequest $request, Brmagazin $brmagazin)
    {
        try {
            $data = $request->all();

            $brmagazin->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('project::brmagazin.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('project/brmagazin/' . $brmagazin->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('project/brmagazin/' . $brmagazin->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the brmagazin.
     *
     * @param Model   $brmagazin
     *
     * @return Response
     */
    public function destroy(BrmagazinRequest $request, Brmagazin $brmagazin)
    {
        try {
            $brmagazin->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('project::brmagazin.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('project/brmagazin/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('project/brmagazin/' . $brmagazin->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
