<?php

namespace Project\Project\Policies;

use Litepie\User\Contracts\UserPolicy;
use Project\Project\Models\Brmagazin;

class BrmagazinPolicy
{

    /**
     * Determine if the given user can view the brmagazin.
     *
     * @param UserPolicy $user
     * @param Brmagazin $brmagazin
     *
     * @return bool
     */
    public function view(UserPolicy $user, Brmagazin $brmagazin)
    {
        if ($user->canDo('project.brmagazin.view') && $user->isAdmin()) {
            return true;
        }

        return $brmagazin->user_id == user_id() && $brmagazin->user_type == user_type();
    }

    /**
     * Determine if the given user can create a brmagazin.
     *
     * @param UserPolicy $user
     * @param Brmagazin $brmagazin
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('project.brmagazin.create');
    }

    /**
     * Determine if the given user can update the given brmagazin.
     *
     * @param UserPolicy $user
     * @param Brmagazin $brmagazin
     *
     * @return bool
     */
    public function update(UserPolicy $user, Brmagazin $brmagazin)
    {
        if ($user->canDo('project.brmagazin.edit') && $user->isAdmin()) {
            return true;
        }

        return $brmagazin->user_id == user_id() && $brmagazin->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given brmagazin.
     *
     * @param UserPolicy $user
     * @param Brmagazin $brmagazin
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Brmagazin $brmagazin)
    {
        return $brmagazin->user_id == user_id() && $brmagazin->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given brmagazin.
     *
     * @param UserPolicy $user
     * @param Brmagazin $brmagazin
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Brmagazin $brmagazin)
    {
        if ($user->canDo('project.brmagazin.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given brmagazin.
     *
     * @param UserPolicy $user
     * @param Brmagazin $brmagazin
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Brmagazin $brmagazin)
    {
        if ($user->canDo('project.brmagazin.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
